# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.internal.v1 import proxy_pb2 as aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2


class InternalProxyServiceStub(object):
    """Definition for the internal API that is used to communicate with all internal
    components.

    All uploads should follow this procedure:
    1. Init a new upload.
    2. Create a Upload Presigned URL (The URL should contain a specifier for the
    upload and part id)
    3. Use the presigned URL to upload individual parts, 1-x times.
    4. When all parts are uploaded, call FinishPresignedUpload to complete the
    upload and provide the parts list.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitMultipartUpload = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/InitMultipartUpload',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitMultipartUploadRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitMultipartUploadResponse.FromString,
                )
        self.FinishMultipartUpload = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/FinishMultipartUpload',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishMultipartUploadRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishMultipartUploadResponse.FromString,
                )
        self.DeleteObject = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyService/DeleteObject',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.DeleteObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.DeleteObjectResponse.FromString,
                )


class InternalProxyServiceServicer(object):
    """Definition for the internal API that is used to communicate with all internal
    components.

    All uploads should follow this procedure:
    1. Init a new upload.
    2. Create a Upload Presigned URL (The URL should contain a specifier for the
    upload and part id)
    3. Use the presigned URL to upload individual parts, 1-x times.
    4. When all parts are uploaded, call FinishPresignedUpload to complete the
    upload and provide the parts list.

    """

    def InitMultipartUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinishMultipartUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InternalProxyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitMultipartUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.InitMultipartUpload,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitMultipartUploadRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitMultipartUploadResponse.SerializeToString,
            ),
            'FinishMultipartUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.FinishMultipartUpload,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishMultipartUploadRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishMultipartUploadResponse.SerializeToString,
            ),
            'DeleteObject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteObject,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.DeleteObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.DeleteObjectResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.internal.v1.InternalProxyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InternalProxyService(object):
    """Definition for the internal API that is used to communicate with all internal
    components.

    All uploads should follow this procedure:
    1. Init a new upload.
    2. Create a Upload Presigned URL (The URL should contain a specifier for the
    upload and part id)
    3. Use the presigned URL to upload individual parts, 1-x times.
    4. When all parts are uploaded, call FinishPresignedUpload to complete the
    upload and provide the parts list.

    """

    @staticmethod
    def InitMultipartUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/InitMultipartUpload',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitMultipartUploadRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.InitMultipartUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinishMultipartUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/FinishMultipartUpload',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishMultipartUploadRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinishMultipartUploadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyService/DeleteObject',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.DeleteObjectRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.DeleteObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class InternalProxyNotifierServiceStub(object):
    """This service enables a "return" channel for dataproxy to aruna server communication
    Mainly used to notify the backend of validation / move events after the upload of new files
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOrCreateObjectByPath = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyNotifierService/GetOrCreateObjectByPath',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateObjectByPathRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateObjectByPathResponse.FromString,
                )
        self.FinalizeObject = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyNotifierService/FinalizeObject',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinalizeObjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinalizeObjectResponse.FromString,
                )
        self.GetOrCreateEncryptionKey = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyNotifierService/GetOrCreateEncryptionKey',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateEncryptionKeyRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateEncryptionKeyResponse.FromString,
                )
        self.GetObjectLocation = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyNotifierService/GetObjectLocation',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetObjectLocationRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetObjectLocationResponse.FromString,
                )
        self.GetCollectionByBucket = channel.unary_unary(
                '/aruna.api.internal.v1.InternalProxyNotifierService/GetCollectionByBucket',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetCollectionByBucketRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetCollectionByBucketResponse.FromString,
                )


class InternalProxyNotifierServiceServicer(object):
    """This service enables a "return" channel for dataproxy to aruna server communication
    Mainly used to notify the backend of validation / move events after the upload of new files
    """

    def GetOrCreateObjectByPath(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FinalizeObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrCreateEncryptionKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectLocation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollectionByBucket(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InternalProxyNotifierServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetOrCreateObjectByPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrCreateObjectByPath,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateObjectByPathRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateObjectByPathResponse.SerializeToString,
            ),
            'FinalizeObject': grpc.unary_unary_rpc_method_handler(
                    servicer.FinalizeObject,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinalizeObjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinalizeObjectResponse.SerializeToString,
            ),
            'GetOrCreateEncryptionKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrCreateEncryptionKey,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateEncryptionKeyRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateEncryptionKeyResponse.SerializeToString,
            ),
            'GetObjectLocation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectLocation,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetObjectLocationRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetObjectLocationResponse.SerializeToString,
            ),
            'GetCollectionByBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollectionByBucket,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetCollectionByBucketRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetCollectionByBucketResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.internal.v1.InternalProxyNotifierService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InternalProxyNotifierService(object):
    """This service enables a "return" channel for dataproxy to aruna server communication
    Mainly used to notify the backend of validation / move events after the upload of new files
    """

    @staticmethod
    def GetOrCreateObjectByPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyNotifierService/GetOrCreateObjectByPath',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateObjectByPathRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateObjectByPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FinalizeObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyNotifierService/FinalizeObject',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinalizeObjectRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.FinalizeObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrCreateEncryptionKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyNotifierService/GetOrCreateEncryptionKey',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateEncryptionKeyRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetOrCreateEncryptionKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectLocation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyNotifierService/GetObjectLocation',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetObjectLocationRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetObjectLocationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollectionByBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalProxyNotifierService/GetCollectionByBucket',
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetCollectionByBucketRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_proxy__pb2.GetCollectionByBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/internal/v1/notification.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.notification.services.v1 import notification_service_pb2 as aruna_dot_api_dot_notification_dot_services_dot_v1_dot_notification__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(aruna/api/internal/v1/notification.proto\x12\x15\x61runa.api.internal.v1\x1a\x1bgoogle/api/visibility.proto\x1a(aruna/api/storage/models/v1/models.proto\x1a=aruna/api/notification/services/v1/notification_service.proto\"\xc0\x02\n\x0f\x45mittedResource\x12\x42\n\x07project\x18\x01 \x01(\x0b\x32&.aruna.api.internal.v1.ProjectResourceH\x00R\x07project\x12K\n\ncollection\x18\x02 \x01(\x0b\x32).aruna.api.internal.v1.CollectionResourceH\x00R\ncollection\x12?\n\x06object\x18\x03 \x01(\x0b\x32%.aruna.api.internal.v1.ObjectResourceH\x00R\x06object\x12O\n\x0cobject_group\x18\x04 \x01(\x0b\x32*.aruna.api.internal.v1.ObjectGroupResourceH\x00R\x0bobjectGroupB\n\n\x08resource\"0\n\x0fProjectResource\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"X\n\x12\x43ollectionResource\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\"\x9b\x01\n\x0eObjectResource\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12(\n\x10shared_object_id\x18\x03 \x01(\tR\x0esharedObjectId\x12\x1b\n\tobject_id\x18\x04 \x01(\tR\x08objectId\"\xb6\x01\n\x13ObjectGroupResource\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12\x33\n\x16shared_object_group_id\x18\x03 \x01(\tR\x13sharedObjectGroupId\x12&\n\x0fobject_group_id\x18\x04 \x01(\tR\robjectGroupId\"\x99\x02\n\x10\x45mitEventRequest\x12P\n\x0e\x65vent_resource\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\reventResource\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\x12L\n\nevent_type\x18\x03 \x01(\x0e\x32-.aruna.api.notification.services.v1.EventTypeR\teventType\x12\x44\n\tresources\x18\x04 \x03(\x0b\x32&.aruna.api.internal.v1.EmittedResourceR\tresources\"\x13\n\x11\x45mitEventResponse\"\x91\x02\n\x0bStreamGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12L\n\nevent_type\x18\x02 \x01(\x0e\x32-.aruna.api.notification.services.v1.EventTypeR\teventType\x12N\n\rresource_type\x18\x03 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x0cresourceType\x12\x1f\n\x0bresource_id\x18\x04 \x01(\tR\nresourceId\x12\x33\n\x16notify_on_sub_resource\x18\x05 \x01(\x08R\x13notifyOnSubResource\"\xa4\x02\n\x18\x43reateStreamGroupRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12L\n\nevent_type\x18\x02 \x01(\x0e\x32-.aruna.api.notification.services.v1.EventTypeR\teventType\x12N\n\rresource_type\x18\x03 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x0cresourceType\x12\x1f\n\x0bresource_id\x18\x04 \x01(\tR\nresourceId\x12\x33\n\x16notify_on_sub_resource\x18\x05 \x01(\x08R\x13notifyOnSubResource\"b\n\x19\x43reateStreamGroupResponse\x12\x45\n\x0cstream_group\x18\x01 \x01(\x0b\x32\".aruna.api.internal.v1.StreamGroupR\x0bstreamGroup\"U\n\x15GetStreamGroupRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12&\n\x0fstream_group_id\x18\x02 \x01(\tR\rstreamGroupId\"_\n\x16GetStreamGroupResponse\x12\x45\n\x0cstream_group\x18\x01 \x01(\x0b\x32\".aruna.api.internal.v1.StreamGroupR\x0bstreamGroup\"X\n\x18\x44\x65leteStreamGroupRequest\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12&\n\x0fstream_group_id\x18\x02 \x01(\tR\rstreamGroupId\"\x1b\n\x19\x44\x65leteStreamGroupResponse\"\x8b\x01\n\x18GetSharedRevisionRequest\x12N\n\rresource_type\x18\x01 \x01(\x0e\x32).aruna.api.storage.models.v1.ResourceTypeR\x0cresourceType\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tR\nresourceId\"I\n\x19GetSharedRevisionResponse\x12,\n\x12shared_revision_id\x18\x01 \x01(\tR\x10sharedRevisionId2\x91\x01\n\x1bInternalEventEmitterService\x12`\n\tEmitEvent\x12\'.aruna.api.internal.v1.EmitEventRequest\x1a(.aruna.api.internal.v1.EmitEventResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL2\x87\x04\n\x14InternalEventService\x12x\n\x11\x43reateStreamGroup\x12/.aruna.api.internal.v1.CreateStreamGroupRequest\x1a\x30.aruna.api.internal.v1.CreateStreamGroupResponse\"\x00\x12o\n\x0eGetStreamGroup\x12,.aruna.api.internal.v1.GetStreamGroupRequest\x1a-.aruna.api.internal.v1.GetStreamGroupResponse\"\x00\x12x\n\x11\x44\x65leteStreamGroup\x12/.aruna.api.internal.v1.DeleteStreamGroupRequest\x1a\x30.aruna.api.internal.v1.DeleteStreamGroupResponse\"\x00\x12x\n\x11GetSharedRevision\x12/.aruna.api.internal.v1.GetSharedRevisionRequest\x1a\x30.aruna.api.internal.v1.GetSharedRevisionResponse\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB6Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.internal.v1.notification_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/ArunaStorage/go-api/aruna/api/internal/v1'
  _INTERNALEVENTEMITTERSERVICE._options = None
  _INTERNALEVENTEMITTERSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _INTERNALEVENTSERVICE._options = None
  _INTERNALEVENTSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _EMITTEDRESOURCE._serialized_start=202
  _EMITTEDRESOURCE._serialized_end=522
  _PROJECTRESOURCE._serialized_start=524
  _PROJECTRESOURCE._serialized_end=572
  _COLLECTIONRESOURCE._serialized_start=574
  _COLLECTIONRESOURCE._serialized_end=662
  _OBJECTRESOURCE._serialized_start=665
  _OBJECTRESOURCE._serialized_end=820
  _OBJECTGROUPRESOURCE._serialized_start=823
  _OBJECTGROUPRESOURCE._serialized_end=1005
  _EMITEVENTREQUEST._serialized_start=1008
  _EMITEVENTREQUEST._serialized_end=1289
  _EMITEVENTRESPONSE._serialized_start=1291
  _EMITEVENTRESPONSE._serialized_end=1310
  _STREAMGROUP._serialized_start=1313
  _STREAMGROUP._serialized_end=1586
  _CREATESTREAMGROUPREQUEST._serialized_start=1589
  _CREATESTREAMGROUPREQUEST._serialized_end=1881
  _CREATESTREAMGROUPRESPONSE._serialized_start=1883
  _CREATESTREAMGROUPRESPONSE._serialized_end=1981
  _GETSTREAMGROUPREQUEST._serialized_start=1983
  _GETSTREAMGROUPREQUEST._serialized_end=2068
  _GETSTREAMGROUPRESPONSE._serialized_start=2070
  _GETSTREAMGROUPRESPONSE._serialized_end=2165
  _DELETESTREAMGROUPREQUEST._serialized_start=2167
  _DELETESTREAMGROUPREQUEST._serialized_end=2255
  _DELETESTREAMGROUPRESPONSE._serialized_start=2257
  _DELETESTREAMGROUPRESPONSE._serialized_end=2284
  _GETSHAREDREVISIONREQUEST._serialized_start=2287
  _GETSHAREDREVISIONREQUEST._serialized_end=2426
  _GETSHAREDREVISIONRESPONSE._serialized_start=2428
  _GETSHAREDREVISIONRESPONSE._serialized_end=2501
  _INTERNALEVENTEMITTERSERVICE._serialized_start=2504
  _INTERNALEVENTEMITTERSERVICE._serialized_end=2649
  _INTERNALEVENTSERVICE._serialized_start=2652
  _INTERNALEVENTSERVICE._serialized_end=3171
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.storage.services.v1 import service_account_service_pb2 as aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2


class ServiceAccountServiceStub(object):
    """ServiceAccountService

    Service that contains all methods for service_accounts, these are Accounts that are
    project specific (or global) and can be used for automation. 
    Service account users will always contain (bot) behind their name
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateServiceAccount = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/CreateServiceAccount',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountResponse.FromString,
                )
        self.CreateServiceAccountToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/CreateServiceAccountToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountTokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountTokenResponse.FromString,
                )
        self.EditServiceAccountPermission = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/EditServiceAccountPermission',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.EditServiceAccountPermissionRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.EditServiceAccountPermissionResponse.FromString,
                )
        self.GetServiceAccountToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/GetServiceAccountToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokenResponse.FromString,
                )
        self.GetServiceAccountTokens = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/GetServiceAccountTokens',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokensRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokensResponse.FromString,
                )
        self.GetServiceAccountsByProject = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/GetServiceAccountsByProject',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountsByProjectRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountsByProjectResponse.FromString,
                )
        self.DeleteServiceAccountToken = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/DeleteServiceAccountToken',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokenRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokenResponse.FromString,
                )
        self.DeleteServiceAccountTokens = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/DeleteServiceAccountTokens',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokensRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokensResponse.FromString,
                )
        self.DeleteServiceAccount = channel.unary_unary(
                '/aruna.api.storage.services.v1.ServiceAccountService/DeleteServiceAccount',
                request_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountResponse.FromString,
                )


class ServiceAccountServiceServicer(object):
    """ServiceAccountService

    Service that contains all methods for service_accounts, these are Accounts that are
    project specific (or global) and can be used for automation. 
    Service account users will always contain (bot) behind their name
    """

    def CreateServiceAccount(self, request, context):
        """CreateServiceAccount

        Creates a service account for a given project
        If the service account has permissions for the global Admin project
        it will be a global service account that can interact with any resource
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateServiceAccountToken(self, request, context):
        """CreateServiceAccountToken

        Creates a token for a service account
        Each service account can only have one permission -> The token will have the same permission as the
        service account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditServiceAccountPermission(self, request, context):
        """EditServiceAccountPermission

        Overwrites the project specific permissions for a service account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceAccountToken(self, request, context):
        """GetServiceAccountToken

        This requests the overall information about a specifc service account token (by id)
        it will not contain the token itself.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceAccountTokens(self, request, context):
        """GetServiceAccountTokens

        This requests the overall information about all service account tokens
        it will not contain the token itself.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceAccountsByProject(self, request, context):
        """GetServiceAccountsByProject

        Will request all service_accounts for a given project
        each service account is bound to a specific project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteServiceAccountToken(self, request, context):
        """DeleteServiceAccountToken

        Deletes one service account token by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteServiceAccountTokens(self, request, context):
        """DeleteServiceAccountTokens

        Deletes all service account tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteServiceAccount(self, request, context):
        """DeleteServiceAccount

        Deletes a service account (by id)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateServiceAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateServiceAccount,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountResponse.SerializeToString,
            ),
            'CreateServiceAccountToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateServiceAccountToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountTokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountTokenResponse.SerializeToString,
            ),
            'EditServiceAccountPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.EditServiceAccountPermission,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.EditServiceAccountPermissionRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.EditServiceAccountPermissionResponse.SerializeToString,
            ),
            'GetServiceAccountToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceAccountToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokenResponse.SerializeToString,
            ),
            'GetServiceAccountTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceAccountTokens,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokensRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokensResponse.SerializeToString,
            ),
            'GetServiceAccountsByProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceAccountsByProject,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountsByProjectRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountsByProjectResponse.SerializeToString,
            ),
            'DeleteServiceAccountToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteServiceAccountToken,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokenRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokenResponse.SerializeToString,
            ),
            'DeleteServiceAccountTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteServiceAccountTokens,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokensRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokensResponse.SerializeToString,
            ),
            'DeleteServiceAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteServiceAccount,
                    request_deserializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountRequest.FromString,
                    response_serializer=aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.storage.services.v1.ServiceAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceAccountService(object):
    """ServiceAccountService

    Service that contains all methods for service_accounts, these are Accounts that are
    project specific (or global) and can be used for automation. 
    Service account users will always contain (bot) behind their name
    """

    @staticmethod
    def CreateServiceAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/CreateServiceAccount',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateServiceAccountToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/CreateServiceAccountToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountTokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.CreateServiceAccountTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditServiceAccountPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/EditServiceAccountPermission',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.EditServiceAccountPermissionRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.EditServiceAccountPermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceAccountToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/GetServiceAccountToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceAccountTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/GetServiceAccountTokens',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokensRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceAccountsByProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/GetServiceAccountsByProject',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountsByProjectRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.GetServiceAccountsByProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteServiceAccountToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/DeleteServiceAccountToken',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokenRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteServiceAccountTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/DeleteServiceAccountTokens',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokensRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteServiceAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.storage.services.v1.ServiceAccountService/DeleteServiceAccount',
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountRequest.SerializeToString,
            aruna_dot_api_dot_storage_dot_services_dot_v1_dot_service__account__service__pb2.DeleteServiceAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aruna.api.internal.v1 import authorize_pb2 as aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2


class InternalAuthorizeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Authorize = channel.unary_unary(
                '/aruna.api.internal.v1.InternalAuthorizeService/Authorize',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeResponse.FromString,
                )
        self.GetSecret = channel.unary_unary(
                '/aruna.api.internal.v1.InternalAuthorizeService/GetSecret',
                request_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretResponse.FromString,
                )


class InternalAuthorizeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Authorize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InternalAuthorizeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Authorize': grpc.unary_unary_rpc_method_handler(
                    servicer.Authorize,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeResponse.SerializeToString,
            ),
            'GetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecret,
                    request_deserializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretRequest.FromString,
                    response_serializer=aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aruna.api.internal.v1.InternalAuthorizeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InternalAuthorizeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Authorize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalAuthorizeService/Authorize',
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.AuthorizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aruna.api.internal.v1.InternalAuthorizeService/GetSecret',
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretRequest.SerializeToString,
            aruna_dot_api_dot_internal_dot_v1_dot_authorize__pb2.GetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.api import visibility_pb2 as _visibility_pb2
from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from aruna.api.notification.services.v1 import notification_service_pb2 as _notification_service_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CollectionResource(_message.Message):
    __slots__ = ["collection_id", "project_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ...) -> None: ...

class CreateStreamGroupRequest(_message.Message):
    __slots__ = ["event_type", "notify_on_sub_resource", "resource_id", "resource_type", "token"]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    NOTIFY_ON_SUB_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    event_type: _notification_service_pb2.EventType
    notify_on_sub_resource: bool
    resource_id: str
    resource_type: _models_pb2.ResourceType
    token: str
    def __init__(self, token: _Optional[str] = ..., event_type: _Optional[_Union[_notification_service_pb2.EventType, str]] = ..., resource_type: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., notify_on_sub_resource: bool = ...) -> None: ...

class CreateStreamGroupResponse(_message.Message):
    __slots__ = ["stream_group"]
    STREAM_GROUP_FIELD_NUMBER: _ClassVar[int]
    stream_group: StreamGroup
    def __init__(self, stream_group: _Optional[_Union[StreamGroup, _Mapping]] = ...) -> None: ...

class DeleteStreamGroupRequest(_message.Message):
    __slots__ = ["stream_group_id", "token"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    token: str
    def __init__(self, token: _Optional[str] = ..., stream_group_id: _Optional[str] = ...) -> None: ...

class DeleteStreamGroupResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EmitEventRequest(_message.Message):
    __slots__ = ["event_resource", "event_type", "resource_id", "resources"]
    EVENT_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    event_resource: _models_pb2.ResourceType
    event_type: _notification_service_pb2.EventType
    resource_id: str
    resources: _containers.RepeatedCompositeFieldContainer[EmittedResource]
    def __init__(self, event_resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., event_type: _Optional[_Union[_notification_service_pb2.EventType, str]] = ..., resources: _Optional[_Iterable[_Union[EmittedResource, _Mapping]]] = ...) -> None: ...

class EmitEventResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EmittedResource(_message.Message):
    __slots__ = ["collection", "object", "object_group", "project"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUP_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    collection: CollectionResource
    object: ObjectResource
    object_group: ObjectGroupResource
    project: ProjectResource
    def __init__(self, project: _Optional[_Union[ProjectResource, _Mapping]] = ..., collection: _Optional[_Union[CollectionResource, _Mapping]] = ..., object: _Optional[_Union[ObjectResource, _Mapping]] = ..., object_group: _Optional[_Union[ObjectGroupResource, _Mapping]] = ...) -> None: ...

class GetSharedRevisionRequest(_message.Message):
    __slots__ = ["resource_id", "resource_type"]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    resource_type: _models_pb2.ResourceType
    def __init__(self, resource_type: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ...) -> None: ...

class GetSharedRevisionResponse(_message.Message):
    __slots__ = ["shared_revision_id"]
    SHARED_REVISION_ID_FIELD_NUMBER: _ClassVar[int]
    shared_revision_id: str
    def __init__(self, shared_revision_id: _Optional[str] = ...) -> None: ...

class GetStreamGroupRequest(_message.Message):
    __slots__ = ["stream_group_id", "token"]
    STREAM_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    stream_group_id: str
    token: str
    def __init__(self, token: _Optional[str] = ..., stream_group_id: _Optional[str] = ...) -> None: ...

class GetStreamGroupResponse(_message.Message):
    __slots__ = ["stream_group"]
    STREAM_GROUP_FIELD_NUMBER: _ClassVar[int]
    stream_group: StreamGroup
    def __init__(self, stream_group: _Optional[_Union[StreamGroup, _Mapping]] = ...) -> None: ...

class ObjectGroupResource(_message.Message):
    __slots__ = ["collection_id", "object_group_id", "project_id", "shared_object_group_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SHARED_OBJECT_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_group_id: str
    project_id: str
    shared_object_group_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., shared_object_group_id: _Optional[str] = ..., object_group_id: _Optional[str] = ...) -> None: ...

class ObjectResource(_message.Message):
    __slots__ = ["collection_id", "object_id", "project_id", "shared_object_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SHARED_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    object_id: str
    project_id: str
    shared_object_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., shared_object_id: _Optional[str] = ..., object_id: _Optional[str] = ...) -> None: ...

class ProjectResource(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class StreamGroup(_message.Message):
    __slots__ = ["event_type", "id", "notify_on_sub_resource", "resource_id", "resource_type"]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NOTIFY_ON_SUB_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    event_type: _notification_service_pb2.EventType
    id: str
    notify_on_sub_resource: bool
    resource_id: str
    resource_type: _models_pb2.ResourceType
    def __init__(self, id: _Optional[str] = ..., event_type: _Optional[_Union[_notification_service_pb2.EventType, str]] = ..., resource_type: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., resource_id: _Optional[str] = ..., notify_on_sub_resource: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4aruna/api/storage/services/v1/endpoint_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\x1cgoogle/api/annotations.proto\"\xa4\x02\n\x12\x41\x64\x64\x45ndpointRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x42\n\x07\x65p_type\x18\x02 \x01(\x0e\x32).aruna.api.storage.models.v1.EndpointTypeR\x06\x65pType\x12%\n\x0eproxy_hostname\x18\x03 \x01(\tR\rproxyHostname\x12+\n\x11internal_hostname\x18\x04 \x01(\tR\x10internalHostname\x12-\n\x12\x64ocumentation_path\x18\x05 \x01(\tR\x11\x64ocumentationPath\x12\x1b\n\tis_public\x18\x06 \x01(\x08R\x08isPublic\x12\x16\n\x06pubkey\x18\x07 \x01(\tR\x06pubkey\"}\n\x13\x41\x64\x64\x45ndpointResponse\x12\x41\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\x08\x65ndpoint\x12#\n\rpubkey_serial\x18\x02 \x01(\x03R\x0cpubkeySerial\"j\n\x12GetEndpointRequest\x12%\n\rendpoint_name\x18\x01 \x01(\tH\x00R\x0c\x65ndpointName\x12!\n\x0b\x65ndpoint_id\x18\x02 \x01(\tH\x00R\nendpointIdB\n\n\x08\x65ndpoint\"X\n\x13GetEndpointResponse\x12\x41\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\x08\x65ndpoint\"\x15\n\x13GetEndpointsRequest\"[\n\x14GetEndpointsResponse\x12\x43\n\tendpoints\x18\x01 \x03(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\tendpoints\"8\n\x15\x44\x65leteEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\x01 \x01(\tR\nendpointId\"\x18\n\x16\x44\x65leteEndpointResponse\"\x1b\n\x19GetDefaultEndpointRequest\"_\n\x1aGetDefaultEndpointResponse\x12\x41\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32%.aruna.api.storage.models.v1.EndpointR\x08\x65ndpoint2\x8d\x06\n\x0f\x45ndpointService\x12\x8d\x01\n\x0b\x41\x64\x64\x45ndpoint\x12\x31.aruna.api.storage.services.v1.AddEndpointRequest\x1a\x32.aruna.api.storage.services.v1.AddEndpointResponse\"\x17\x82\xd3\xe4\x93\x02\x11:\x01*\"\x0c/v1/endpoint\x12\x8a\x01\n\x0bGetEndpoint\x12\x31.aruna.api.storage.services.v1.GetEndpointRequest\x1a\x32.aruna.api.storage.services.v1.GetEndpointResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/endpoint\x12\x8e\x01\n\x0cGetEndpoints\x12\x32.aruna.api.storage.services.v1.GetEndpointsRequest\x1a\x33.aruna.api.storage.services.v1.GetEndpointsResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/endpoints\x12\xa1\x01\n\x0e\x44\x65leteEndpoint\x12\x34.aruna.api.storage.services.v1.DeleteEndpointRequest\x1a\x35.aruna.api.storage.services.v1.DeleteEndpointResponse\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/endpoint/{endpoint_id}\x12\xa7\x01\n\x12GetDefaultEndpoint\x12\x38.aruna.api.storage.services.v1.GetDefaultEndpointRequest\x1a\x39.aruna.api.storage.services.v1.GetDefaultEndpointResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/endpoint/defaultB\x91\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x0f\x45ndpointServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.endpoint_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\017EndpointServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _ENDPOINTSERVICE.methods_by_name['AddEndpoint']._options = None
  _ENDPOINTSERVICE.methods_by_name['AddEndpoint']._serialized_options = b'\202\323\344\223\002\021:\001*\"\014/v1/endpoint'
  _ENDPOINTSERVICE.methods_by_name['GetEndpoint']._options = None
  _ENDPOINTSERVICE.methods_by_name['GetEndpoint']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/endpoint'
  _ENDPOINTSERVICE.methods_by_name['GetEndpoints']._options = None
  _ENDPOINTSERVICE.methods_by_name['GetEndpoints']._serialized_options = b'\202\323\344\223\002\017\022\r/v1/endpoints'
  _ENDPOINTSERVICE.methods_by_name['DeleteEndpoint']._options = None
  _ENDPOINTSERVICE.methods_by_name['DeleteEndpoint']._serialized_options = b'\202\323\344\223\002\034*\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['GetDefaultEndpoint']._options = None
  _ENDPOINTSERVICE.methods_by_name['GetDefaultEndpoint']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/endpoint/default'
  _ADDENDPOINTREQUEST._serialized_start=160
  _ADDENDPOINTREQUEST._serialized_end=452
  _ADDENDPOINTRESPONSE._serialized_start=454
  _ADDENDPOINTRESPONSE._serialized_end=579
  _GETENDPOINTREQUEST._serialized_start=581
  _GETENDPOINTREQUEST._serialized_end=687
  _GETENDPOINTRESPONSE._serialized_start=689
  _GETENDPOINTRESPONSE._serialized_end=777
  _GETENDPOINTSREQUEST._serialized_start=779
  _GETENDPOINTSREQUEST._serialized_end=800
  _GETENDPOINTSRESPONSE._serialized_start=802
  _GETENDPOINTSRESPONSE._serialized_end=893
  _DELETEENDPOINTREQUEST._serialized_start=895
  _DELETEENDPOINTREQUEST._serialized_end=951
  _DELETEENDPOINTRESPONSE._serialized_start=953
  _DELETEENDPOINTRESPONSE._serialized_end=977
  _GETDEFAULTENDPOINTREQUEST._serialized_start=979
  _GETDEFAULTENDPOINTREQUEST._serialized_end=1006
  _GETDEFAULTENDPOINTRESPONSE._serialized_start=1008
  _GETDEFAULTENDPOINTRESPONSE._serialized_end=1103
  _ENDPOINTSERVICE._serialized_start=1106
  _ENDPOINTSERVICE._serialized_end=1887
# @@protoc_insertion_point(module_scope)



from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LabelFilter(_message.Message):
    __slots__ = ["and_or_or", "keys_only", "labels"]
    AND_OR_OR_FIELD_NUMBER: _ClassVar[int]
    KEYS_ONLY_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    and_or_or: bool
    keys_only: bool
    labels: _containers.RepeatedCompositeFieldContainer[_models_pb2.KeyValue]
    def __init__(self, labels: _Optional[_Iterable[_Union[_models_pb2.KeyValue, _Mapping]]] = ..., and_or_or: bool = ..., keys_only: bool = ...) -> None: ...

class LabelOrIDQuery(_message.Message):
    __slots__ = ["ids", "labels"]
    IDS_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    labels: LabelFilter
    def __init__(self, labels: _Optional[_Union[LabelFilter, _Mapping]] = ..., ids: _Optional[_Iterable[str]] = ...) -> None: ...

class PageRequest(_message.Message):
    __slots__ = ["last_uuid", "page_size"]
    LAST_UUID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    last_uuid: str
    page_size: int
    def __init__(self, last_uuid: _Optional[str] = ..., page_size: _Optional[int] = ...) -> None: ...



from google.api import visibility_pb2 as _visibility_pb2
from aruna.api.storage.models.v1 import models_pb2 as _models_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
ID_TYPE_PATH: IdType
ID_TYPE_UNSPECIFIED: IdType
ID_TYPE_UUID: IdType

class Authorization(_message.Message):
    __slots__ = ["accesskey", "secretkey"]
    ACCESSKEY_FIELD_NUMBER: _ClassVar[int]
    SECRETKEY_FIELD_NUMBER: _ClassVar[int]
    accesskey: str
    secretkey: str
    def __init__(self, secretkey: _Optional[str] = ..., accesskey: _Optional[str] = ...) -> None: ...

class AuthorizeRequest(_message.Message):
    __slots__ = ["authorization", "identifier", "resource", "resource_action"]
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ACTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    authorization: Authorization
    identifier: Identifier
    resource: _models_pb2.ResourceType
    resource_action: _models_pb2.ResourceAction
    def __init__(self, resource: _Optional[_Union[_models_pb2.ResourceType, str]] = ..., identifier: _Optional[_Union[Identifier, _Mapping]] = ..., resource_action: _Optional[_Union[_models_pb2.ResourceAction, str]] = ..., authorization: _Optional[_Union[Authorization, _Mapping]] = ...) -> None: ...

class AuthorizeResponse(_message.Message):
    __slots__ = ["ok"]
    OK_FIELD_NUMBER: _ClassVar[int]
    ok: bool
    def __init__(self, ok: bool = ...) -> None: ...

class GetSecretRequest(_message.Message):
    __slots__ = ["accesskey"]
    ACCESSKEY_FIELD_NUMBER: _ClassVar[int]
    accesskey: str
    def __init__(self, accesskey: _Optional[str] = ...) -> None: ...

class GetSecretResponse(_message.Message):
    __slots__ = ["authorization"]
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    authorization: Authorization
    def __init__(self, authorization: _Optional[_Union[Authorization, _Mapping]] = ...) -> None: ...

class Identifier(_message.Message):
    __slots__ = ["idtype", "name"]
    IDTYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    idtype: IdType
    name: str
    def __init__(self, name: _Optional[str] = ..., idtype: _Optional[_Union[IdType, str]] = ...) -> None: ...

class IdType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from aruna.api.storage.models.v1 import auth_pb2 as _auth_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActivateUserRequest(_message.Message):
    __slots__ = ["project_perms", "user_id"]
    PROJECT_PERMS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    project_perms: _auth_pb2.ProjectPermission
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., project_perms: _Optional[_Union[_auth_pb2.ProjectPermission, _Mapping]] = ...) -> None: ...

class ActivateUserResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateAPITokenRequest(_message.Message):
    __slots__ = ["collection_id", "expires_at", "is_session", "name", "permission", "project_id"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    IS_SESSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    expires_at: ExpiresAt
    is_session: bool
    name: str
    permission: _auth_pb2.Permission
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., collection_id: _Optional[str] = ..., name: _Optional[str] = ..., expires_at: _Optional[_Union[ExpiresAt, _Mapping]] = ..., permission: _Optional[_Union[_auth_pb2.Permission, str]] = ..., is_session: bool = ...) -> None: ...

class CreateAPITokenResponse(_message.Message):
    __slots__ = ["s3_access_key", "s3_secret_key", "token", "token_secret"]
    S3_ACCESS_KEY_FIELD_NUMBER: _ClassVar[int]
    S3_SECRET_KEY_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_SECRET_FIELD_NUMBER: _ClassVar[int]
    s3_access_key: str
    s3_secret_key: str
    token: _auth_pb2.Token
    token_secret: str
    def __init__(self, token: _Optional[_Union[_auth_pb2.Token, _Mapping]] = ..., token_secret: _Optional[str] = ..., s3_access_key: _Optional[str] = ..., s3_secret_key: _Optional[str] = ...) -> None: ...

class DeactivateUserRequest(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class DeactivateUserResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteAPITokenRequest(_message.Message):
    __slots__ = ["token_id"]
    TOKEN_ID_FIELD_NUMBER: _ClassVar[int]
    token_id: str
    def __init__(self, token_id: _Optional[str] = ...) -> None: ...

class DeleteAPITokenResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteAPITokensRequest(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class DeleteAPITokensResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ExpiresAt(_message.Message):
    __slots__ = ["timestamp"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetAPITokenRequest(_message.Message):
    __slots__ = ["token_id"]
    TOKEN_ID_FIELD_NUMBER: _ClassVar[int]
    token_id: str
    def __init__(self, token_id: _Optional[str] = ...) -> None: ...

class GetAPITokenResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: _auth_pb2.Token
    def __init__(self, token: _Optional[_Union[_auth_pb2.Token, _Mapping]] = ...) -> None: ...

class GetAPITokensRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetAPITokensResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: _containers.RepeatedCompositeFieldContainer[_auth_pb2.Token]
    def __init__(self, token: _Optional[_Iterable[_Union[_auth_pb2.Token, _Mapping]]] = ...) -> None: ...

class GetAllUsersRequest(_message.Message):
    __slots__ = ["include_permissions"]
    INCLUDE_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    include_permissions: bool
    def __init__(self, include_permissions: bool = ...) -> None: ...

class GetAllUsersResponse(_message.Message):
    __slots__ = ["user_with_perms"]
    USER_WITH_PERMS_FIELD_NUMBER: _ClassVar[int]
    user_with_perms: _containers.RepeatedCompositeFieldContainer[UserWithPerms]
    def __init__(self, user_with_perms: _Optional[_Iterable[_Union[UserWithPerms, _Mapping]]] = ...) -> None: ...

class GetNotActivatedUsersRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetNotActivatedUsersResponse(_message.Message):
    __slots__ = ["users"]
    USERS_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[_auth_pb2.User]
    def __init__(self, users: _Optional[_Iterable[_Union[_auth_pb2.User, _Mapping]]] = ...) -> None: ...

class GetUserProjectsRequest(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class GetUserProjectsResponse(_message.Message):
    __slots__ = ["projects"]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[UserProject]
    def __init__(self, projects: _Optional[_Iterable[_Union[UserProject, _Mapping]]] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ["project_permissions", "user"]
    PROJECT_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    project_permissions: _containers.RepeatedCompositeFieldContainer[_auth_pb2.ProjectPermission]
    user: _auth_pb2.User
    def __init__(self, user: _Optional[_Union[_auth_pb2.User, _Mapping]] = ..., project_permissions: _Optional[_Iterable[_Union[_auth_pb2.ProjectPermission, _Mapping]]] = ...) -> None: ...

class RegisterUserRequest(_message.Message):
    __slots__ = ["display_name", "email", "project"]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    email: str
    project: str
    def __init__(self, display_name: _Optional[str] = ..., email: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class RegisterUserResponse(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class UpdateUserDisplayNameRequest(_message.Message):
    __slots__ = ["new_display_name"]
    NEW_DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    new_display_name: str
    def __init__(self, new_display_name: _Optional[str] = ...) -> None: ...

class UpdateUserDisplayNameResponse(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _auth_pb2.User
    def __init__(self, user: _Optional[_Union[_auth_pb2.User, _Mapping]] = ...) -> None: ...

class UpdateUserEmailRequest(_message.Message):
    __slots__ = ["new_email", "user_id"]
    NEW_EMAIL_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    new_email: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., new_email: _Optional[str] = ...) -> None: ...

class UpdateUserEmailResponse(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _auth_pb2.User
    def __init__(self, user: _Optional[_Union[_auth_pb2.User, _Mapping]] = ...) -> None: ...

class UserProject(_message.Message):
    __slots__ = ["description", "id", "name"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    description: str
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class UserWithPerms(_message.Message):
    __slots__ = ["project_perms", "user"]
    PROJECT_PERMS_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    project_perms: _containers.RepeatedCompositeFieldContainer[_auth_pb2.ProjectPermission]
    user: _auth_pb2.User
    def __init__(self, user: _Optional[_Union[_auth_pb2.User, _Mapping]] = ..., project_perms: _Optional[_Iterable[_Union[_auth_pb2.ProjectPermission, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/models/v1/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&aruna/api/storage/models/v1/auth.proto\x12\x1b\x61runa.api.storage.models.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x01\n\x07Project\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12Y\n\x10user_permissions\x18\x03 \x03(\x0b\x32..aruna.api.storage.models.v1.ProjectPermissionR\x0fuserPermissions\x12%\n\x0e\x63ollection_ids\x18\x04 \x03(\tR\rcollectionIds\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\"\x99\x01\n\x0fProjectOverview\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12%\n\x0e\x63ollection_ids\x18\x04 \x03(\tR\rcollectionIds\x12\x19\n\x08user_ids\x18\x05 \x03(\tR\x07userIds\"\xd1\x01\n\x04User\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x19\n\x08is_admin\x18\x05 \x01(\x08R\x07isAdmin\x12,\n\x12is_service_account\x18\x06 \x01(\x08R\x10isServiceAccount\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\"\xc9\x03\n\x05Token\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x45\n\ntoken_type\x18\x04 \x01(\x0e\x32&.aruna.api.storage.models.v1.TokenTypeR\ttokenType\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nexpires_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12#\n\rcollection_id\x18\x07 \x01(\tR\x0c\x63ollectionId\x12\x1d\n\nproject_id\x18\x08 \x01(\tR\tprojectId\x12G\n\npermission\x18\t \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\x12\x1d\n\nis_session\x18\n \x01(\x08R\tisSession\x12\x33\n\x07used_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x06usedAt\"\xbd\x01\n\x11ProjectPermission\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12G\n\npermission\x18\x03 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\x12\'\n\x0fservice_account\x18\x04 \x01(\x08R\x0eserviceAccount\"\xc2\x01\n\x1cProjectPermissionDisplayName\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12G\n\npermission\x18\x03 \x01(\x0e\x32\'.aruna.api.storage.models.v1.PermissionR\npermission\x12!\n\x0c\x64isplay_name\x18\x04 \x01(\tR\x0b\x64isplayName*\x96\x01\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x13\n\x0fPERMISSION_NONE\x10\x01\x12\x13\n\x0fPERMISSION_READ\x10\x02\x12\x15\n\x11PERMISSION_APPEND\x10\x03\x12\x15\n\x11PERMISSION_MODIFY\x10\x04\x12\x14\n\x10PERMISSION_ADMIN\x10\x05*g\n\x08PermType\x12\x19\n\x15PERM_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0ePERM_TYPE_USER\x10\x01\x12\x17\n\x13PERM_TYPE_ANONYMOUS\x10\x02\x12\x13\n\x0fPERM_TYPE_TOKEN\x10\x03*W\n\tTokenType\x12\x1a\n\x16TOKEN_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13TOKEN_TYPE_PERSONAL\x10\x01\x12\x15\n\x11TOKEN_TYPE_SCOPED\x10\x02\x42<Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.models.v1.auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/ArunaStorage/go-api/aruna/api/storage/models/v1'
  _PERMISSION._serialized_start=1534
  _PERMISSION._serialized_end=1684
  _PERMTYPE._serialized_start=1686
  _PERMTYPE._serialized_end=1789
  _TOKENTYPE._serialized_start=1791
  _TOKENTYPE._serialized_end=1878
  _PROJECT._serialized_start=105
  _PROJECT._serialized_end=314
  _PROJECTOVERVIEW._serialized_start=317
  _PROJECTOVERVIEW._serialized_end=470
  _USER._serialized_start=473
  _USER._serialized_end=682
  _TOKEN._serialized_start=685
  _TOKEN._serialized_end=1142
  _PROJECTPERMISSION._serialized_start=1145
  _PROJECTPERMISSION._serialized_end=1334
  _PROJECTPERMISSIONDISPLAYNAME._serialized_start=1337
  _PROJECTPERMISSIONDISPLAYNAME._serialized_end=1531
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
PERMISSION_ADMIN: Permission
PERMISSION_APPEND: Permission
PERMISSION_MODIFY: Permission
PERMISSION_NONE: Permission
PERMISSION_READ: Permission
PERMISSION_UNSPECIFIED: Permission
PERM_TYPE_ANONYMOUS: PermType
PERM_TYPE_TOKEN: PermType
PERM_TYPE_UNSPECIFIED: PermType
PERM_TYPE_USER: PermType
TOKEN_TYPE_PERSONAL: TokenType
TOKEN_TYPE_SCOPED: TokenType
TOKEN_TYPE_UNSPECIFIED: TokenType

class Project(_message.Message):
    __slots__ = ["collection_ids", "description", "id", "name", "user_permissions"]
    COLLECTION_IDS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    USER_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    collection_ids: _containers.RepeatedScalarFieldContainer[str]
    description: str
    id: str
    name: str
    user_permissions: _containers.RepeatedCompositeFieldContainer[ProjectPermission]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., user_permissions: _Optional[_Iterable[_Union[ProjectPermission, _Mapping]]] = ..., collection_ids: _Optional[_Iterable[str]] = ..., description: _Optional[str] = ...) -> None: ...

class ProjectOverview(_message.Message):
    __slots__ = ["collection_ids", "description", "id", "name", "user_ids"]
    COLLECTION_IDS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    collection_ids: _containers.RepeatedScalarFieldContainer[str]
    description: str
    id: str
    name: str
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., collection_ids: _Optional[_Iterable[str]] = ..., user_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectPermission(_message.Message):
    __slots__ = ["permission", "project_id", "service_account", "user_id"]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    permission: Permission
    project_id: str
    service_account: bool
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., project_id: _Optional[str] = ..., permission: _Optional[_Union[Permission, str]] = ..., service_account: bool = ...) -> None: ...

class ProjectPermissionDisplayName(_message.Message):
    __slots__ = ["display_name", "permission", "project_id", "user_id"]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    permission: Permission
    project_id: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., project_id: _Optional[str] = ..., permission: _Optional[_Union[Permission, str]] = ..., display_name: _Optional[str] = ...) -> None: ...

class Token(_message.Message):
    __slots__ = ["collection_id", "created_at", "expires_at", "id", "is_session", "name", "permission", "project_id", "token_type", "used_at"]
    COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_SESSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    USED_AT_FIELD_NUMBER: _ClassVar[int]
    collection_id: str
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    id: str
    is_session: bool
    name: str
    permission: Permission
    project_id: str
    token_type: TokenType
    used_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., token_type: _Optional[_Union[TokenType, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., collection_id: _Optional[str] = ..., project_id: _Optional[str] = ..., permission: _Optional[_Union[Permission, str]] = ..., is_session: bool = ..., used_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ["active", "display_name", "email", "external_id", "id", "is_admin", "is_service_account"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_ADMIN_FIELD_NUMBER: _ClassVar[int]
    IS_SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    active: bool
    display_name: str
    email: str
    external_id: str
    id: str
    is_admin: bool
    is_service_account: bool
    def __init__(self, id: _Optional[str] = ..., external_id: _Optional[str] = ..., display_name: _Optional[str] = ..., active: bool = ..., is_admin: bool = ..., is_service_account: bool = ..., email: _Optional[str] = ...) -> None: ...

class Permission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class PermType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class TokenType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DATA_CLASS_CONFIDENTIAL: DataClass
DATA_CLASS_PRIVATE: DataClass
DATA_CLASS_PROTECTED: DataClass
DATA_CLASS_PUBLIC: DataClass
DATA_CLASS_UNSPECIFIED: DataClass
DESCRIPTOR: _descriptor.FileDescriptor
ENDPOINT_STATUS_AVAILABLE: EndpointStatus
ENDPOINT_STATUS_DEGRADED: EndpointStatus
ENDPOINT_STATUS_INITIALIZING: EndpointStatus
ENDPOINT_STATUS_MAINTENANCE: EndpointStatus
ENDPOINT_STATUS_UNAVAILABLE: EndpointStatus
ENDPOINT_STATUS_UNSPECIFIED: EndpointStatus
ENDPOINT_TYPE_FILE: EndpointType
ENDPOINT_TYPE_S3: EndpointType
ENDPOINT_TYPE_UNSPECIFIED: EndpointType
HASHALGORITHM_MD5: Hashalgorithm
HASHALGORITHM_SHA256: Hashalgorithm
HASHALGORITHM_UNSPECIFIED: Hashalgorithm
RESOURCE_ACTION_APPEND: ResourceAction
RESOURCE_ACTION_CREATE: ResourceAction
RESOURCE_ACTION_DELETE: ResourceAction
RESOURCE_ACTION_READ: ResourceAction
RESOURCE_ACTION_UNSPECIFIED: ResourceAction
RESOURCE_ACTION_UPDATE: ResourceAction
RESOURCE_TYPE_ALL: ResourceType
RESOURCE_TYPE_COLLECTION: ResourceType
RESOURCE_TYPE_OBJECT: ResourceType
RESOURCE_TYPE_OBJECT_GROUP: ResourceType
RESOURCE_TYPE_PROJECT: ResourceType
RESOURCE_TYPE_UNSPECIFIED: ResourceType
SOURCE_TYPE_DOI: SourceType
SOURCE_TYPE_UNSPECIFIED: SourceType
SOURCE_TYPE_URL: SourceType
STATUS_AVAILABLE: Status
STATUS_ERROR: Status
STATUS_FINALIZING: Status
STATUS_INITIALIZING: Status
STATUS_TRASH: Status
STATUS_UNAVAILABLE: Status
STATUS_UNSPECIFIED: Status

class Collection(_message.Message):
    __slots__ = ["created", "description", "hooks", "id", "is_public", "label_ontology", "labels", "latest", "name", "object_groups", "objects", "semantic_version", "specifications", "stats"]
    CREATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LABEL_ONTOLOGY_FIELD_NUMBER: _ClassVar[int]
    LATEST_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    SEMANTIC_VERSION_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATIONS_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    created: _timestamp_pb2.Timestamp
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    is_public: bool
    label_ontology: LabelOntology
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    latest: bool
    name: str
    object_groups: _containers.RepeatedCompositeFieldContainer[ObjectGroup]
    objects: _containers.RepeatedCompositeFieldContainer[Object]
    semantic_version: Version
    specifications: _containers.RepeatedCompositeFieldContainer[Object]
    stats: CollectionStats
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., label_ontology: _Optional[_Union[LabelOntology, _Mapping]] = ..., created: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., objects: _Optional[_Iterable[_Union[Object, _Mapping]]] = ..., specifications: _Optional[_Iterable[_Union[Object, _Mapping]]] = ..., object_groups: _Optional[_Iterable[_Union[ObjectGroup, _Mapping]]] = ..., semantic_version: _Optional[_Union[Version, _Mapping]] = ..., latest: bool = ..., stats: _Optional[_Union[CollectionStats, _Mapping]] = ..., is_public: bool = ...) -> None: ...

class CollectionOverview(_message.Message):
    __slots__ = ["created", "description", "hooks", "id", "is_public", "label_ontology", "labels", "latest", "name", "semantic_version", "stats"]
    CREATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LABEL_ONTOLOGY_FIELD_NUMBER: _ClassVar[int]
    LATEST_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SEMANTIC_VERSION_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    created: _timestamp_pb2.Timestamp
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    is_public: bool
    label_ontology: LabelOntology
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    latest: bool
    name: str
    semantic_version: Version
    stats: CollectionStats
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., label_ontology: _Optional[_Union[LabelOntology, _Mapping]] = ..., created: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., semantic_version: _Optional[_Union[Version, _Mapping]] = ..., latest: bool = ..., stats: _Optional[_Union[CollectionStats, _Mapping]] = ..., is_public: bool = ...) -> None: ...

class CollectionOverviews(_message.Message):
    __slots__ = ["collection_overviews"]
    COLLECTION_OVERVIEWS_FIELD_NUMBER: _ClassVar[int]
    collection_overviews: _containers.RepeatedCompositeFieldContainer[CollectionOverview]
    def __init__(self, collection_overviews: _Optional[_Iterable[_Union[CollectionOverview, _Mapping]]] = ...) -> None: ...

class CollectionStats(_message.Message):
    __slots__ = ["last_updated", "object_group_count", "object_stats"]
    LAST_UPDATED_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUP_COUNT_FIELD_NUMBER: _ClassVar[int]
    OBJECT_STATS_FIELD_NUMBER: _ClassVar[int]
    last_updated: _timestamp_pb2.Timestamp
    object_group_count: int
    object_stats: Stats
    def __init__(self, object_stats: _Optional[_Union[Stats, _Mapping]] = ..., object_group_count: _Optional[int] = ..., last_updated: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CollectionWithID(_message.Message):
    __slots__ = ["created", "description", "hooks", "id", "is_public", "label_ontology", "labels", "latest", "name", "object_groups", "objects", "semantic_version", "specifications", "stats"]
    CREATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LABEL_ONTOLOGY_FIELD_NUMBER: _ClassVar[int]
    LATEST_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    SEMANTIC_VERSION_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATIONS_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    created: _timestamp_pb2.Timestamp
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    is_public: bool
    label_ontology: LabelOntology
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    latest: bool
    name: str
    object_groups: _containers.RepeatedScalarFieldContainer[str]
    objects: _containers.RepeatedScalarFieldContainer[str]
    semantic_version: Version
    specifications: _containers.RepeatedScalarFieldContainer[str]
    stats: CollectionStats
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., label_ontology: _Optional[_Union[LabelOntology, _Mapping]] = ..., created: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., objects: _Optional[_Iterable[str]] = ..., specifications: _Optional[_Iterable[str]] = ..., object_groups: _Optional[_Iterable[str]] = ..., semantic_version: _Optional[_Union[Version, _Mapping]] = ..., latest: bool = ..., stats: _Optional[_Union[CollectionStats, _Mapping]] = ..., is_public: bool = ...) -> None: ...

class CollectionWithIDs(_message.Message):
    __slots__ = ["collection_with_ids"]
    COLLECTION_WITH_IDS_FIELD_NUMBER: _ClassVar[int]
    collection_with_ids: _containers.RepeatedCompositeFieldContainer[CollectionWithID]
    def __init__(self, collection_with_ids: _Optional[_Iterable[_Union[CollectionWithID, _Mapping]]] = ...) -> None: ...

class Collections(_message.Message):
    __slots__ = ["collections"]
    COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    collections: _containers.RepeatedCompositeFieldContainer[Collection]
    def __init__(self, collections: _Optional[_Iterable[_Union[Collection, _Mapping]]] = ...) -> None: ...

class Endpoint(_message.Message):
    __slots__ = ["documentation_path", "ep_type", "id", "internal_hostname", "is_default", "is_public", "name", "proxy_hostname", "status"]
    DOCUMENTATION_PATH_FIELD_NUMBER: _ClassVar[int]
    EP_TYPE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    IS_DEFAULT_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROXY_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    documentation_path: str
    ep_type: EndpointType
    id: str
    internal_hostname: str
    is_default: bool
    is_public: bool
    name: str
    proxy_hostname: str
    status: EndpointStatus
    def __init__(self, id: _Optional[str] = ..., ep_type: _Optional[_Union[EndpointType, str]] = ..., name: _Optional[str] = ..., proxy_hostname: _Optional[str] = ..., internal_hostname: _Optional[str] = ..., documentation_path: _Optional[str] = ..., is_public: bool = ..., is_default: bool = ..., status: _Optional[_Union[EndpointStatus, str]] = ...) -> None: ...

class Hash(_message.Message):
    __slots__ = ["alg", "hash"]
    ALG_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    alg: Hashalgorithm
    hash: str
    def __init__(self, alg: _Optional[_Union[Hashalgorithm, str]] = ..., hash: _Optional[str] = ...) -> None: ...

class KeyValue(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class LabelOntology(_message.Message):
    __slots__ = ["required_label_keys"]
    REQUIRED_LABEL_KEYS_FIELD_NUMBER: _ClassVar[int]
    required_label_keys: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, required_label_keys: _Optional[_Iterable[str]] = ...) -> None: ...

class Object(_message.Message):
    __slots__ = ["auto_update", "content_len", "created", "data_class", "filename", "hashes", "hooks", "id", "labels", "latest", "origin", "rev_number", "source", "status"]
    AUTO_UPDATE_FIELD_NUMBER: _ClassVar[int]
    CONTENT_LEN_FIELD_NUMBER: _ClassVar[int]
    CREATED_FIELD_NUMBER: _ClassVar[int]
    DATA_CLASS_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    HASHES_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LATEST_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    REV_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    auto_update: bool
    content_len: int
    created: _timestamp_pb2.Timestamp
    data_class: DataClass
    filename: str
    hashes: _containers.RepeatedCompositeFieldContainer[Hash]
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    latest: bool
    origin: Origin
    rev_number: int
    source: Source
    status: Status
    def __init__(self, id: _Optional[str] = ..., filename: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., created: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., content_len: _Optional[int] = ..., status: _Optional[_Union[Status, str]] = ..., origin: _Optional[_Union[Origin, _Mapping]] = ..., data_class: _Optional[_Union[DataClass, str]] = ..., hashes: _Optional[_Iterable[_Union[Hash, _Mapping]]] = ..., rev_number: _Optional[int] = ..., source: _Optional[_Union[Source, _Mapping]] = ..., latest: bool = ..., auto_update: bool = ...) -> None: ...

class ObjectGroup(_message.Message):
    __slots__ = ["description", "hooks", "id", "labels", "meta_objects", "name", "objects", "rev_number", "stats"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    META_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    REV_NUMBER_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    meta_objects: _containers.RepeatedCompositeFieldContainer[Object]
    name: str
    objects: _containers.RepeatedCompositeFieldContainer[Object]
    rev_number: int
    stats: ObjectGroupStats
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., objects: _Optional[_Iterable[_Union[Object, _Mapping]]] = ..., meta_objects: _Optional[_Iterable[_Union[Object, _Mapping]]] = ..., stats: _Optional[_Union[ObjectGroupStats, _Mapping]] = ..., rev_number: _Optional[int] = ...) -> None: ...

class ObjectGroupOverview(_message.Message):
    __slots__ = ["description", "hooks", "id", "labels", "name", "rev_number", "stats"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REV_NUMBER_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    name: str
    rev_number: int
    stats: ObjectGroupStats
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., stats: _Optional[_Union[ObjectGroupStats, _Mapping]] = ..., rev_number: _Optional[int] = ...) -> None: ...

class ObjectGroupOverviews(_message.Message):
    __slots__ = ["object_group_overviews"]
    OBJECT_GROUP_OVERVIEWS_FIELD_NUMBER: _ClassVar[int]
    object_group_overviews: _containers.RepeatedCompositeFieldContainer[ObjectGroupOverview]
    def __init__(self, object_group_overviews: _Optional[_Iterable[_Union[ObjectGroupOverview, _Mapping]]] = ...) -> None: ...

class ObjectGroupStats(_message.Message):
    __slots__ = ["last_updated", "object_stats"]
    LAST_UPDATED_FIELD_NUMBER: _ClassVar[int]
    OBJECT_STATS_FIELD_NUMBER: _ClassVar[int]
    last_updated: _timestamp_pb2.Timestamp
    object_stats: Stats
    def __init__(self, object_stats: _Optional[_Union[Stats, _Mapping]] = ..., last_updated: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ObjectGroupWithID(_message.Message):
    __slots__ = ["description", "hooks", "id", "labels", "meta_object_ids", "name", "object_ids", "rev_number", "stats"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HOOKS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    META_OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    REV_NUMBER_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    description: str
    hooks: _containers.RepeatedCompositeFieldContainer[KeyValue]
    id: str
    labels: _containers.RepeatedCompositeFieldContainer[KeyValue]
    meta_object_ids: _containers.RepeatedScalarFieldContainer[str]
    name: str
    object_ids: _containers.RepeatedScalarFieldContainer[str]
    rev_number: int
    stats: ObjectGroupStats
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., hooks: _Optional[_Iterable[_Union[KeyValue, _Mapping]]] = ..., object_ids: _Optional[_Iterable[str]] = ..., meta_object_ids: _Optional[_Iterable[str]] = ..., stats: _Optional[_Union[ObjectGroupStats, _Mapping]] = ..., rev_number: _Optional[int] = ...) -> None: ...

class ObjectGroupWithIDs(_message.Message):
    __slots__ = ["object_group_with_ids"]
    OBJECT_GROUP_WITH_IDS_FIELD_NUMBER: _ClassVar[int]
    object_group_with_ids: _containers.RepeatedCompositeFieldContainer[ObjectGroupWithID]
    def __init__(self, object_group_with_ids: _Optional[_Iterable[_Union[ObjectGroupWithID, _Mapping]]] = ...) -> None: ...

class ObjectGroups(_message.Message):
    __slots__ = ["object_groups"]
    OBJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    object_groups: _containers.RepeatedCompositeFieldContainer[ObjectGroup]
    def __init__(self, object_groups: _Optional[_Iterable[_Union[ObjectGroup, _Mapping]]] = ...) -> None: ...

class Objects(_message.Message):
    __slots__ = ["objects"]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    objects: _containers.RepeatedCompositeFieldContainer[Object]
    def __init__(self, objects: _Optional[_Iterable[_Union[Object, _Mapping]]] = ...) -> None: ...

class Origin(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class Source(_message.Message):
    __slots__ = ["identifier", "source_type"]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    source_type: SourceType
    def __init__(self, identifier: _Optional[str] = ..., source_type: _Optional[_Union[SourceType, str]] = ...) -> None: ...

class Stats(_message.Message):
    __slots__ = ["acc_size", "count"]
    ACC_SIZE_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    acc_size: int
    count: int
    def __init__(self, count: _Optional[int] = ..., acc_size: _Optional[int] = ...) -> None: ...

class Version(_message.Message):
    __slots__ = ["major", "minor", "patch"]
    MAJOR_FIELD_NUMBER: _ClassVar[int]
    MINOR_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    major: int
    minor: int
    patch: int
    def __init__(self, major: _Optional[int] = ..., minor: _Optional[int] = ..., patch: _Optional[int] = ...) -> None: ...

class ResourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class ResourceAction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class EndpointStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Hashalgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class DataClass(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class SourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class EndpointType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aruna/api/storage/services/v1/objectgroup_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aruna.api.storage.models.v1 import models_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_models__pb2
from aruna.api.storage.models.v1 import query_pb2 as aruna_dot_api_dot_storage_dot_models_dot_v1_dot_query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7aruna/api/storage/services/v1/objectgroup_service.proto\x12\x1d\x61runa.api.storage.services.v1\x1a(aruna/api/storage/models/v1/models.proto\x1a\'aruna/api/storage/models/v1/query.proto\x1a\x1cgoogle/api/annotations.proto\"\xb8\x02\n\x18\x43reateObjectGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12#\n\rcollection_id\x18\x03 \x01(\tR\x0c\x63ollectionId\x12\x1d\n\nobject_ids\x18\x04 \x03(\tR\tobjectIds\x12&\n\x0fmeta_object_ids\x18\x05 \x03(\tR\rmetaObjectIds\x12=\n\x06labels\x18\x06 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"p\n\x19\x43reateObjectGroupResponse\x12S\n\x0cobject_group\x18\x01 \x01(\x0b\x32\x30.aruna.api.storage.models.v1.ObjectGroupOverviewR\x0bobjectGroup\"\xd3\x02\n\x18UpdateObjectGroupRequest\x12\x19\n\x08group_id\x18\x01 \x01(\tR\x07groupId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12#\n\rcollection_id\x18\x04 \x01(\tR\x0c\x63ollectionId\x12\x1d\n\nobject_ids\x18\x05 \x03(\tR\tobjectIds\x12&\n\x0fmeta_object_ids\x18\x06 \x03(\tR\rmetaObjectIds\x12=\n\x06labels\x18\x07 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x06labels\x12;\n\x05hooks\x18\x08 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x05hooks\"p\n\x19UpdateObjectGroupResponse\x12S\n\x0cobject_group\x18\x01 \x01(\x0b\x32\x30.aruna.api.storage.models.v1.ObjectGroupOverviewR\x0bobjectGroup\"[\n\x19GetObjectGroupByIdRequest\x12\x19\n\x08group_id\x18\x01 \x01(\tR\x07groupId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\"q\n\x1aGetObjectGroupByIdResponse\x12S\n\x0cobject_group\x18\x01 \x01(\x0b\x32\x30.aruna.api.storage.models.v1.ObjectGroupOverviewR\x0bobjectGroup\"\xb1\x01\n GetObjectGroupsFromObjectRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\"{\n!GetObjectGroupsFromObjectResponse\x12V\n\robject_groups\x18\x01 \x01(\x0b\x32\x31.aruna.api.storage.models.v1.ObjectGroupOverviewsR\x0cobjectGroups\"\x81\x01\n\x18\x44\x65leteObjectGroupRequest\x12\x19\n\x08group_id\x18\x01 \x01(\tR\x07groupId\x12#\n\rcollection_id\x18\x02 \x01(\tR\x0c\x63ollectionId\x12%\n\x0ewith_revisions\x18\x03 \x01(\x08R\rwithRevisions\"\x1b\n\x19\x44\x65leteObjectGroupResponse\"\xdf\x01\n\x16GetObjectGroupsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12K\n\x0cpage_request\x18\x02 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12S\n\x0flabel_id_filter\x18\x03 \x01(\x0b\x32+.aruna.api.storage.models.v1.LabelOrIDQueryR\rlabelIdFilter\"q\n\x17GetObjectGroupsResponse\x12V\n\robject_groups\x18\x01 \x01(\x0b\x32\x31.aruna.api.storage.models.v1.ObjectGroupOverviewsR\x0cobjectGroups\"\xab\x01\n\x1cGetObjectGroupHistoryRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\"w\n\x1dGetObjectGroupHistoryResponse\x12V\n\robject_groups\x18\x01 \x01(\x0b\x32\x31.aruna.api.storage.models.v1.ObjectGroupOverviewsR\x0cobjectGroups\"\xc8\x01\n\x1cGetObjectGroupObjectsRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\x12K\n\x0cpage_request\x18\x03 \x01(\x0b\x32(.aruna.api.storage.models.v1.PageRequestR\x0bpageRequest\x12\x1b\n\tmeta_only\x18\x04 \x01(\x08R\x08metaOnly\"q\n\x11ObjectGroupObject\x12;\n\x06object\x18\x01 \x01(\x0b\x32#.aruna.api.storage.models.v1.ObjectR\x06object\x12\x1f\n\x0bis_metadata\x18\x02 \x01(\x08R\nisMetadata\"\x83\x01\n\x1dGetObjectGroupObjectsResponse\x12\x62\n\x14object_group_objects\x18\x01 \x03(\x0b\x32\x30.aruna.api.storage.services.v1.ObjectGroupObjectR\x12objectGroupObjects\"\xaa\x01\n\x1d\x41\x64\x64LabelsToObjectGroupRequest\x12#\n\rcollection_id\x18\x01 \x01(\tR\x0c\x63ollectionId\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\x12I\n\rlabels_to_add\x18\x03 \x03(\x0b\x32%.aruna.api.storage.models.v1.KeyValueR\x0blabelsToAdd\"u\n\x1e\x41\x64\x64LabelsToObjectGroupResponse\x12S\n\x0cobject_group\x18\x01 \x01(\x0b\x32\x30.aruna.api.storage.models.v1.ObjectGroupOverviewR\x0bobjectGroup2\xba\x0e\n\x12ObjectGroupService\x12\xb7\x01\n\x11\x43reateObjectGroup\x12\x37.aruna.api.storage.services.v1.CreateObjectGroupRequest\x1a\x38.aruna.api.storage.services.v1.CreateObjectGroupResponse\"/\x82\xd3\xe4\x93\x02):\x01*\"$/v1/collection/{collection_id}/group\x12\xc2\x01\n\x11UpdateObjectGroup\x12\x37.aruna.api.storage.services.v1.UpdateObjectGroupRequest\x1a\x38.aruna.api.storage.services.v1.UpdateObjectGroupResponse\":\x82\xd3\xe4\x93\x02\x34:\x01*\"//v1/collection/{collection_id}/group/{group_id}\x12\xc2\x01\n\x12GetObjectGroupById\x12\x38.aruna.api.storage.services.v1.GetObjectGroupByIdRequest\x1a\x39.aruna.api.storage.services.v1.GetObjectGroupByIdResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/collection/{collection_id}/group/{group_id}\x12\xe0\x01\n\x19GetObjectGroupsFromObject\x12?.aruna.api.storage.services.v1.GetObjectGroupsFromObjectRequest\x1a@.aruna.api.storage.services.v1.GetObjectGroupsFromObjectResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/collection/{collection_id}/object/{object_id}/groups\x12\xaf\x01\n\x0fGetObjectGroups\x12\x35.aruna.api.storage.services.v1.GetObjectGroupsRequest\x1a\x36.aruna.api.storage.services.v1.GetObjectGroupsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/collection/{collection_id}/groups\x12\xd3\x01\n\x15GetObjectGroupHistory\x12;.aruna.api.storage.services.v1.GetObjectGroupHistoryRequest\x1a<.aruna.api.storage.services.v1.GetObjectGroupHistoryResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/v1/collection/{collection_id}/group/{group_id}/history\x12\xd3\x01\n\x15GetObjectGroupObjects\x12;.aruna.api.storage.services.v1.GetObjectGroupObjectsRequest\x1a<.aruna.api.storage.services.v1.GetObjectGroupObjectsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/v1/collection/{collection_id}/group/{group_id}/objects\x12\xbf\x01\n\x11\x44\x65leteObjectGroup\x12\x37.aruna.api.storage.services.v1.DeleteObjectGroupRequest\x1a\x38.aruna.api.storage.services.v1.DeleteObjectGroupResponse\"7\x82\xd3\xe4\x93\x02\x31*//v1/collection/{collection_id}/group/{group_id}\x12\xdc\x01\n\x16\x41\x64\x64LabelsToObjectGroup\x12<.aruna.api.storage.services.v1.AddLabelsToObjectGroupRequest\x1a=.aruna.api.storage.services.v1.AddLabelsToObjectGroupResponse\"E\x82\xd3\xe4\x93\x02?:\x01*2:/v1/collection/{collection_id}/group/{group_id}/add_labelsB\x94\x01\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\x12ObjectGroupServiceP\x01Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aruna.api.storage.services.v1.objectgroup_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>com.github.ArunaStorage.java_api.aruna.api.storage.services.v1B\022ObjectGroupServiceP\001Z<github.com/ArunaStorage/go-api/aruna/api/storage/services/v1'
  _OBJECTGROUPSERVICE.methods_by_name['CreateObjectGroup']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['CreateObjectGroup']._serialized_options = b'\202\323\344\223\002):\001*\"$/v1/collection/{collection_id}/group'
  _OBJECTGROUPSERVICE.methods_by_name['UpdateObjectGroup']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['UpdateObjectGroup']._serialized_options = b'\202\323\344\223\0024:\001*\"//v1/collection/{collection_id}/group/{group_id}'
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupById']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupById']._serialized_options = b'\202\323\344\223\0021\022//v1/collection/{collection_id}/group/{group_id}'
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupsFromObject']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupsFromObject']._serialized_options = b'\202\323\344\223\002:\0228/v1/collection/{collection_id}/object/{object_id}/groups'
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroups']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroups']._serialized_options = b'\202\323\344\223\002\'\022%/v1/collection/{collection_id}/groups'
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupHistory']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupHistory']._serialized_options = b'\202\323\344\223\0029\0227/v1/collection/{collection_id}/group/{group_id}/history'
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupObjects']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['GetObjectGroupObjects']._serialized_options = b'\202\323\344\223\0029\0227/v1/collection/{collection_id}/group/{group_id}/objects'
  _OBJECTGROUPSERVICE.methods_by_name['DeleteObjectGroup']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['DeleteObjectGroup']._serialized_options = b'\202\323\344\223\0021*//v1/collection/{collection_id}/group/{group_id}'
  _OBJECTGROUPSERVICE.methods_by_name['AddLabelsToObjectGroup']._options = None
  _OBJECTGROUPSERVICE.methods_by_name['AddLabelsToObjectGroup']._serialized_options = b'\202\323\344\223\002?:\001*2:/v1/collection/{collection_id}/group/{group_id}/add_labels'
  _CREATEOBJECTGROUPREQUEST._serialized_start=204
  _CREATEOBJECTGROUPREQUEST._serialized_end=516
  _CREATEOBJECTGROUPRESPONSE._serialized_start=518
  _CREATEOBJECTGROUPRESPONSE._serialized_end=630
  _UPDATEOBJECTGROUPREQUEST._serialized_start=633
  _UPDATEOBJECTGROUPREQUEST._serialized_end=972
  _UPDATEOBJECTGROUPRESPONSE._serialized_start=974
  _UPDATEOBJECTGROUPRESPONSE._serialized_end=1086
  _GETOBJECTGROUPBYIDREQUEST._serialized_start=1088
  _GETOBJECTGROUPBYIDREQUEST._serialized_end=1179
  _GETOBJECTGROUPBYIDRESPONSE._serialized_start=1181
  _GETOBJECTGROUPBYIDRESPONSE._serialized_end=1294
  _GETOBJECTGROUPSFROMOBJECTREQUEST._serialized_start=1297
  _GETOBJECTGROUPSFROMOBJECTREQUEST._serialized_end=1474
  _GETOBJECTGROUPSFROMOBJECTRESPONSE._serialized_start=1476
  _GETOBJECTGROUPSFROMOBJECTRESPONSE._serialized_end=1599
  _DELETEOBJECTGROUPREQUEST._serialized_start=1602
  _DELETEOBJECTGROUPREQUEST._serialized_end=1731
  _DELETEOBJECTGROUPRESPONSE._serialized_start=1733
  _DELETEOBJECTGROUPRESPONSE._serialized_end=1760
  _GETOBJECTGROUPSREQUEST._serialized_start=1763
  _GETOBJECTGROUPSREQUEST._serialized_end=1986
  _GETOBJECTGROUPSRESPONSE._serialized_start=1988
  _GETOBJECTGROUPSRESPONSE._serialized_end=2101
  _GETOBJECTGROUPHISTORYREQUEST._serialized_start=2104
  _GETOBJECTGROUPHISTORYREQUEST._serialized_end=2275
  _GETOBJECTGROUPHISTORYRESPONSE._serialized_start=2277
  _GETOBJECTGROUPHISTORYRESPONSE._serialized_end=2396
  _GETOBJECTGROUPOBJECTSREQUEST._serialized_start=2399
  _GETOBJECTGROUPOBJECTSREQUEST._serialized_end=2599
  _OBJECTGROUPOBJECT._serialized_start=2601
  _OBJECTGROUPOBJECT._serialized_end=2714
  _GETOBJECTGROUPOBJECTSRESPONSE._serialized_start=2717
  _GETOBJECTGROUPOBJECTSRESPONSE._serialized_end=2848
  _ADDLABELSTOOBJECTGROUPREQUEST._serialized_start=2851
  _ADDLABELSTOOBJECTGROUPREQUEST._serialized_end=3021
  _ADDLABELSTOOBJECTGROUPRESPONSE._serialized_start=3023
  _ADDLABELSTOOBJECTGROUPRESPONSE._serialized_end=3140
  _OBJECTGROUPSERVICE._serialized_start=3143
  _OBJECTGROUPSERVICE._serialized_end=4993
# @@protoc_insertion_point(module_scope)
